svn commit: samba r17359 - in branches/SAMBA_4_0/source/ntvfs/posix: .

metze at samba.org metze at samba.org
Tue Aug 1 10:11:37 GMT 2006


Author: metze
Date: 2006-08-01 10:11:37 +0000 (Tue, 01 Aug 2006)
New Revision: 17359

WebSVN: http://websvn.samba.org/cgi-bin/viewcvs.cgi?view=rev&root=samba&rev=17359

Log:
http://www.cs.wisc.edu/~cao/cs739/draft-leach-cifs-v1-spec-01.txt
says that with the 0xffff fid all files only for the given pid
should be flushed

Does samba3 handle this correct?

metze
Modified:
   branches/SAMBA_4_0/source/ntvfs/posix/pvfs_flush.c


Changeset:
Modified: branches/SAMBA_4_0/source/ntvfs/posix/pvfs_flush.c
===================================================================
--- branches/SAMBA_4_0/source/ntvfs/posix/pvfs_flush.c	2006-08-01 09:25:24 UTC (rev 17358)
+++ branches/SAMBA_4_0/source/ntvfs/posix/pvfs_flush.c	2006-08-01 10:11:37 UTC (rev 17359)
@@ -62,8 +62,13 @@
 			return NT_STATUS_OK;
 		}
 
 		/* they are asking to flush all open files */
 		for (f=pvfs->files.list;f;f=f->next) {
+			if (f->smbpid != req->smbpid) continue;
+
 			pvfs_flush_file(pvfs, f);
 		}
 
@@ -62,8 +62,13 @@
 		}
 
-		/* they are asking to flush all open files */
+		/* 
+		 * they are asking to flush all open files
+		 * for the given SMBPID
+		 */
 		for (f=pvfs->files.list;f;f=f->next) {



More information about the samba-cvs mailing list